/* PrintFamilyPage.java
 *
 * Jim McBeath, January 26, 1997
 */

package jimmc.roots;

class PrintFamilyPage extends PrintFormat {
	public PrintFamilyPage(CommandInterpreter ci){super(ci);}
	public String getName() {
		return "fampage";
	}
	public RecordFormat getDefaultRecordFormat() {
		return new FormatBrief(ci);
	}
	/** Print a family page of each RootsUnion record in the list. */
	public void printRecords(PrintOptions po, RootsRecord ra[]) {
		if (ra==null || ra.length==0)
			return;
		RecordFormat rf = po.recordFormat;
		MultiColumnPrintStream ps = new MultiColumnPrintStream(po.out);
		ps.addColumn(39,1);	/* two columns */
		ps.addColumn(39,0);
		po.out = ps;
		for (int i=0; i<ra.length; i++) {
			if (ra[i] instanceof RootsUnion) {
				RootsUnion ru = (RootsUnion)(ra[i]);
				printFamilyPage(po,ps,ru);
			} else if (ra[i] instanceof RootsPerson) {
				RootsPerson rp = (RootsPerson)(ra[i]);
				RootsRecord[] rr = rp.findReference("union");
				if (rr!=null) {
				  for (int r=0; r<rr.length; r++) {
				    if (rr[r] instanceof RootsUnion) {
				        RootsUnion ru = (RootsUnion)(rr[r]);
					printFamilyPage(po,ps,ru);
				    }
				  }
				}
			}
		}
		ps.flush();
	}

	private void printFamilyPage(PrintOptions po,
			MultiColumnPrintStream ps, RootsUnion ru) {
		RecordFormat rf = po.recordFormat;
		ps.selectDirect();
		ps.printlnc(rf.formatRecord(po,ru));
		ps.println();
		ps.selectColumn(0);
		if (ru.husband!=null)
			ps.printlnc(rf.formatRecord(po,ru.husband));
		ps.selectColumn(1);
		if (ru.wife!=null)
			ps.printlnc(rf.formatRecord(po,ru.wife));
		ps.selectDirect();
		ps.println("----------------------------------------"+
			   "---------------------------------------");
		if (ru.children!=null) {
			for (int i=0; i<ru.children.length; i++) {
				if (i>0) {
					ps.selectDirect();
					ps.println();
				}
				printChild(po,ps,ru.children[i]);
			}
		}
		ps.selectDirect();
		ps.println("========================================"+
			   "=======================================");
	}
	/* Print one child in the family, plus all spouses of that child */
	private void printChild(PrintOptions po,
			MultiColumnPrintStream ps, RootsPerson p){
		RecordFormat rf = po.recordFormat;
		ps.selectColumn(0);
		ps.printlnc(rf.formatRecord(po,p));
		if (p.spouses!=null) {
			ps.selectColumn(1);
			for (int i=0; i<p.spouses.length; i++) {
				if (i>0)
					ps.println();
				printChildSpouse(po,ps,p,p.spouses[i]);
			}
		}
	}
	/* Print one spouse */
	private void printChildSpouse(PrintOptions po,
				MultiColumnPrintStream ps,
				RootsPerson p, RootsUnion m) {
		RootsPerson s;	/* the spouse */
		RecordFormat rf = po.recordFormat;
		StringBuffer sb = new StringBuffer();
		if (po.includeKeys)
			m.formatKey(sb);
		m.formatBriefBody(sb);
		if (sb.length()>0)
			ps.printlnc(sb.toString());
		if (p==m.husband)
			s = m.wife;
		else
			s = m.husband;
		if (s!=null) {
			ps.printlnc(rf.formatRecord(po,s));
		}
	}
}

/* end */
