/* Copyright 1997 Jim McBeath.
 */
/* PrintFormat.java
 *
 * Jim McBeath, January 26, 1997
 */

package jimmc.roots;

public abstract class PrintFormat implements PrintHelp {
	/** Get the name of this format.
	 * @return the name of this format. */
	public abstract String getName();

	protected CommandInterpreter ci;

	/** Set up common stuff for subclasses. */
	public PrintFormat(CommandInterpreter ci) {
		this.ci = ci;
	}

	/** Get the default record format for this print format.
	 * @return default format, or null if no default
	 */
	public RecordFormat getDefaultRecordFormat() {
		return null;
	}

	/** Print the specified records in this format.
	 * @param po the print control options
	 * @param ra the records to print
	 */
	public abstract void printRecords(PrintOptions po,RootsRecord ra[]);

	/** Print out short help */
	public void printOneLineHelp() {
		ci.base.println(getName());
	}

	/** Add the default print formats */
	public static void AddDefaultFormats(CommandInterpreter ci) {
		ci.addPrintFormat(new PrintAtree(ci));
		ci.addPrintFormat(new PrintDtree(ci));
		ci.addPrintFormat(new PrintFamilyPage(ci));
		ci.addPrintFormat(new PrintList(ci));
		ci.addPrintFormat(new PrintListBlank(ci));
	}
}

/* end */
