/* Copyright 1997 Jim McBeath
 *
 * Jim McBeath, January 20, 1997
 */

package jimmc.roots;

import java.io.PrintWriter;

/** PrintOptions is used to pass around all of the information about
 * how the user wants output to be printed.
 */
public class PrintOptions implements Cloneable {
	/** Where to send the output */
	public PrintWriter out;
	/** The overall report format in which to print */
	public PrintFormat reportFormat;
	/** The format of each record. */
	public RecordFormat recordFormat;
	/** True if we should include key data in the output */
	public boolean includeKeys = false;

	public PrintOptions() {
		out = new PrintWriter(System.out);
	}
	public PrintOptions(PrintFormat f, RecordFormat r) {
		this();
		reportFormat = f;
		recordFormat = r;
	}

	/** Print the specified records.
	 * Uses the formats contained in this object.
	 */
	public void printRecords(RootsRecord ra[]) {
		reportFormat.printRecords(this,ra);
	}

	/** Clone the object. */
	protected Object clone() {
		PrintOptions po = new PrintOptions();
		po.out = this.out;
		po.reportFormat = this.reportFormat;
		po.recordFormat = this.recordFormat;
		po.includeKeys = this.includeKeys;
		return po;
	}
}

/* end */
