/* Copyright 1997 Jim McBeath.
 */
/* RecordFormat.java
 *
 * Jim McBeath, January 27, 1997
 */

package jimmc.roots;

public abstract class RecordFormat implements PrintHelp {
	/** Get the name of this format.
	 * @return the name of this format. */
	public abstract String getName();

	protected CommandInterpreter ci;

	/** Set up common stuff for subclasses. */
	public RecordFormat(CommandInterpreter ci) {
		this.ci = ci;
	}

	/** Format the specified record in this format.
	 * @param po the print options to control the format
	 * @param r the record to format
	 * @return the formatted data */
	public abstract String formatRecord(PrintOptions po, RootsRecord r);

	/** Print out a one-line help */
	public void printOneLineHelp() {
		ci.base.println(getName());
	}

	/* Add the default record formats */
	public static void AddDefaultFormats(CommandInterpreter ci) {
		ci.addRecordFormat(new FormatBrief(ci));
		ci.addRecordFormat(new FormatGedcom(ci));
		ci.addRecordFormat(new FormatKeyLine(ci));
		ci.addRecordFormat(new FormatNcv(ci));
		ci.addRecordFormat(new FormatMedium(ci));
		ci.addRecordFormat(new FormatOneLine(ci));
	}
}

/* end */
