package jimmc.roots;

import java.awt.*;
import java.awt.event.MouseEvent;

/** A TextArea with an associated PopupMenu.
 * The container for the TextArea must also call add(popupMenu).
 */
public class TextAreaWithPopup extends TextArea {
	/** The popup menu to attach to this text area. */
	PopupMenu popupMenu;

	public TextAreaWithPopup(PopupMenu p, int rows, int cols) {
		super(rows,cols);
		popupMenu = p;
		enableEvents(AWTEvent.MOUSE_EVENT_MASK);
	}
	public void processMouseEvent(MouseEvent e) {
		if (e.isPopupTrigger()) {
			showPopupMenu(popupMenu,
				e.getComponent(), e.getX(), e.getY());
		}
		super.processMouseEvent(e);
	}
	protected void showPopupMenu(PopupMenu p, Component c, int x, int y) {
		p.show(c, x, y);
	}
	/** Set our font to a fixed-width font. */
	public void setFixedFont() {
		Font f = getFont();
		if (!f.getFamily().equals("monospaced")) {
			Font ff = new Font(
				"monospaced",f.getStyle(),f.getSize());
			setFont(ff);
		}
	}
	/** Given a pixel Y position within the text area, return the text
	 * position of the beginning of the line of text at that y position. */
	public int yPixelToPosition(int y) {
		Font f = getFont();
		FontMetrics fm = getFontMetrics(f);
		int fontHeight = fm.getHeight();
		int lineNum = y/fontHeight;
		String s = getText();	/* get our text string */
		int nthLineOffset = 0;
		for (int n=0; n<lineNum; n++) {
			int x = s.indexOf('\n',nthLineOffset);
			if (x<0)
				return s.length();
			nthLineOffset = x+1;
		}
		/* At this point, nthLineOffset points to the start of
		 * the line of interest. */
		return nthLineOffset;
	}
}
