/* ComponentPrintDialog.java
 *
 * Jim McBeath, December 3, 2001
 */
//PrintDialog method taken from IQvis

package jimmc.swing;

import jimmc.util.ResourceSource;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.print.PageFormat;
import java.awt.print.Printable;
import java.awt.print.PrinterException;
import java.awt.print.PrinterGraphics;
import java.awt.print.PrinterJob;
import javax.swing.border.Border;
import javax.swing.Icon;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.RepaintManager;

public class ComponentPrintDialog implements Printable {
	/** Our parent. */
	protected Component parent;

	/** Our resource source. */
	protected ResourceSource res;

	/** The component to print. */
	protected Component target;

	/** Our PrinterJob. */
	protected PrinterJob printerJob;

	/** Our page format. */
	protected PageFormat pageFormat;

	/** Our dialog panel. */
	protected JPanel panel;

	/** Create our object. */
	public ComponentPrintDialog(Component parent,
				ResourceSource res, Component target) {
		this.parent = parent;
		this.res = res;
		this.target = target;
		panel = buildPanel();
	}

	/** Create our dialog panel. */
	protected JPanel buildPanel() {
		JPanel p = new JPanel();
		GridBagLayout gbl = new GridBagLayout();
		GridBagConstraints gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.anchor = GridBagConstraints.WEST;
		p.setLayout(gbl);

		JLabel label = new JLabel("This panel is empty.");
		p.add(label);

		return p;
	}

	/** Put up the dialog and let the user set his options.
	 * @return The PrinterJob ready for a call to it's print method,
	 *         or null if cancelled.
	 */
	public boolean printDialog() {
		String title = "Print";	//TBD i18n
		Icon icon = null;	//no icon
		Object[] options = { "Page Setup...", "Preview...",
			"Continue...", "Cancel" };
			//TBD i18n
		Object initialOption = options[1];

		printerJob = PrinterJob.getPrinterJob();
		pageFormat = printerJob.defaultPage();
		pageFormat = printerJob.validatePage(pageFormat);

		int t = -1;
		while (t!=2) {	//loop until he picks "Continue"
			t = JOptionPane.showOptionDialog(
				parent, panel, title,
				JOptionPane.YES_NO_OPTION,
				JOptionPane.PLAIN_MESSAGE,
				icon,
				options, initialOption);
			switch (t) {
			case 3:
				return false;	//cancelled
			case 1:
				(new PrintPreviewer(res,this)).show();
				//Assume the user will print from the Previewer,
				//so we don't need to do anything more here.
				return false;
			case 0:
				//Put up page dialog
				PageFormat pf =
					printerJob.pageDialog(pageFormat);
				if (pf!=pageFormat) {
					pageFormat =printerJob.validatePage(pf);
				}
				break;
			default:
				break;	//do nothing
			}
			//if t==2, we will break out of the loop.
			//if t==0 or t==1, we will go back and put up our
			//  dialog box again.
		}

		//When the user pushes the "Continue" button in our dialog,
		//we get to this point in the code, and we put up the
		//standard Print dialog.

		printerJob.setPrintable(this,pageFormat);
		if (!printerJob.printDialog())
			return false;		//cancelled

		return true;			//ready to print
	}

	/** Print. */
	public void print() throws PrinterException {
		printerJob.print();
	}

    //The Printable interface
    	/** Print our target component. */
	public int print(Graphics g, PageFormat pf, int pageIndex) {
		if (pageIndex>0)
			return NO_SUCH_PAGE;
			//TBD - we should check to see if the target height
			//is large enough to require more than one page;
			//if so, add that amount to the vertical translation
			//and print that page.

		//The default foreground and background colors on printing
		//are both white, which makes it pretty hard to see anything.
		//Set the foreground to black.
		g.setColor(Color.black);


		//Turn off double-buffering before printing so that we don't
		//just get a scaled bitmap image of the buffer, turn it back
		//on when we are done printing.
		RepaintManager rm = RepaintManager.currentManager(target);
		rm.setDoubleBufferingEnabled(false);

		Graphics2D g2 = (Graphics2D)g;
		//Translate out of the non-imageable area
		g2.translate(1.01*pf.getImageableX(),1.01*pf.getImageableY());
		//Scale so that the width of the taget component is
		//displayed exactly in the width of the imaging area.
		double scale = 0.98*pf.getImageableWidth()/target.getWidth();
		g2.scale(scale,scale);

		target.print(g2);

		rm = RepaintManager.currentManager(target);
		rm.setDoubleBufferingEnabled(true);

		return PAGE_EXISTS;
	}
    //End Printable interface
}

/* end */
