/* MoreException.java
 *
 * Jim McBeath, October 6, 2001
 */

package jimmc.util;

import java.io.PrintStream;
import java.io.PrintWriter;

/** A wrapper class to encapsulate an exception with additional information. */
public class MoreException extends RuntimeException {
	/** The throwable (exception) we are wrapping. */
	protected Throwable throwable;

	/** Our additional message string. */
	protected String message;

	/** Create an exception to wrap another exception. */
	public MoreException(Throwable throwable) {
		this.throwable = throwable;
	}

	/** Create a wrapper exception with additional information. */
	public MoreException(Throwable throwable, String message) {
		this.throwable = throwable;
		this.message = message;
	}

	/** Get the message for this exception. */
	public String getMessage() {
		String msg = (message==null)?"":message;
		if (throwable==null)
			return msg;
		return msg+throwable.getMessage();
	}

	/** When printing a traceback, print ours as well as the nested
	 * throwable. */
	public void printStackTrace() {
		super.printStackTrace();
		if (throwable!=null) {
			System.err.print("+");
			throwable.printStackTrace();
		}
	}

	/** When printing a traceback, print ours as well as the nested
	 * throwable. */
	public void printStackTrace(PrintStream s) {
		super.printStackTrace(s);
		if (throwable!=null) {
			s.print("+");
			throwable.printStackTrace(s);
		}
	}

	/** When printing a traceback, print ours as well as the nested
	 * throwable. */
	public void printStackTrace(PrintWriter w) {
		super.printStackTrace(w);
		if (throwable!=null) {
			w.print("+");
			throwable.printStackTrace(w);
		}
	}
}

/* end */
